/***************************************************************************
 *   Copyright (C) 2006 by Jaap Boender   *
 *   Jaap.Boender@pps.jussieu.fr   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <qlayout.h>
#include <kglobal.h>
#include <klocale.h>
#include <kconfig.h>
#include <kapplication.h>
#include <kmessagebox.h>
#include <kiconloader.h>

#include <kdebug.h>

#include "kroll.h"
#include "kroll_settings.h"
#include "kroll_configuration.h"

Kroll::Kroll(const QString& configFile, Type type, int actions, QWidget *parent, const char *name)
    : KPanelApplet(configFile, type, actions, parent, name)
{
    QVBoxLayout *layout = new QVBoxLayout (this, 0, 0);
    m_widget = new KrollWidget (this);
    if (Config ().m_index_method == OneSource)
        m_widget -> setSelectedItem (Config ().m_selected_item);
    applyPreferences ();
    layout -> addWidget (m_widget);
    startTimer (1000 * 60 * 60); // one hour
    m_popupMenu = new KPopupMenu (this);
    m_popupMenu -> insertTitle (SmallIcon ("kroll"), i18n ("Kroll"));
    m_popupMenu -> insertItem (SmallIcon ("kroll"), i18n("&About Kroll"), this, SLOT(showAbout()));
    m_popupMenu -> insertItem (SmallIcon ("help"), i18n("&Help"), this,
    SLOT(showHelp()));
    m_popupMenu -> insertItem (SmallIcon ("configure"), i18n("&Configure Kroll..."), this, SLOT(showPreferences()));
}

Kroll::~Kroll()
{
    Config().setSelectedItem (m_widget->selectedItem());
    Config().write ();
    delete m_widget;
}


void Kroll::about()
{
    KMessageBox::information(0, i18n("Kroll v" VERSION ", (c) 2006 Jaap Boender <Jaap.Boender@pps.jussieu.fr> and the EDOS Project. Distributed under the GNU Public License."));
}


void Kroll::help()
{
    kapp -> invokeHelp (QString::null, "kroll");
}


void Kroll::preferences()
{
    KrollSettings *settings = new KrollSettings (this);
    settings -> updateDialog ();
    if (settings -> exec() == QDialog::Accepted)
    {
        settings -> updateConfiguration();
        Config ().write ();
        if (Config ().m_index_method == OneSource)
            m_widget -> setSelectedItem (Config ().m_selected_item);
        applyPreferences ();
    }
}

void Kroll::applyPreferences ()
{
    m_widget -> clearBundles ();
    QStrListIterator it (Config().m_sources);
    QString s;
    while (s = it.current ())
    {
        ++it;
        KrollBundle *b = new KrollBundle ();
        b -> getFromURL (KURL (s));
        m_widget -> addBundle (b);
    }
    m_widget -> setIndexMethod (Config ().m_index_method);
    if (Config ().m_index_method == Average)
        m_widget -> clearSelectedItem ();
    m_widget -> calculateIndex ();
}

extern "C"
{
    KPanelApplet* init( QWidget *parent, const QString& configFile)
    {
        KGlobal::locale()->insertCatalogue("kroll");
        return new Kroll(configFile, KPanelApplet::Normal,
                             KPanelApplet::About | KPanelApplet::Help | KPanelApplet::Preferences,
                             parent, "kroll");
    }
}


/*!
    \fn Kroll::mousePressEvent (QMouseEvent *e)
 */
void Kroll::mousePressEvent (QMouseEvent *e)
{
    if (e -> button () == QMouseEvent::LeftButton)
        m_widget -> showPopup (pos ());
    else if (e -> button () == QMouseEvent::RightButton)
    {
        m_popupMenu -> popup (mapToGlobal (e -> pos ()));
        m_popupMenu -> exec ();
    }
}


/*!
    \fn Kroll::timerEvent (QTimerEvent *)
 */
void Kroll::timerEvent (QTimerEvent *e)
{
    m_widget -> calculateIndex ();
}
