/***************************************************************************
 *   Copyright (C) 2006 by Jaap Boender   *
 *   Jaap.Boender@pps.jussieu.fr   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KROLL_WIDGET_H
#define KROLL_WIDGET_H

#include <qwidget.h>
#include <qimage.h>
#include <qpixmap.h>
#include <kiconview.h>
#include <kdatetbl.h>

#include "kroll_bundle.h"
#include "kroll_configuration.h"

/**
	@author Jaap Boender <Jaap.Boender@pps.jussieu.fr>
*/
class KrollWidget : public QWidget
{
	Q_OBJECT

public:
    KrollWidget(QWidget *parent = 0, const char *name = 0);
    ~KrollWidget() { delete m_iconView; delete m_popup; };
    void calculateIndex ();
    void setIndexMethod (IndexMethod i) { m_index_method = i; };
    void addBundle (KrollBundle *b) { m_bundles.append (b); };
    void removeBundle (KrollBundle *b) { m_bundles.remove (b); delete b; };
    void clearBundles ();
    QString selectedItem () { return m_selected_item; };
    void setSelectedItem (QString s);
    void clearSelectedItem () { m_selected_item = QString (""); };
protected:
    int m_image_index, m_old_width, m_old_height, m_old_index;
    IndexMethod m_index_method;
    KIconView *m_iconView;
    KPopupFrame *m_popup;
    QString m_imagePath, m_selected_item;
    QImage m_image;
    QPixmap m_pixmap;
    QPtrList<KrollBundle> m_bundles;
    void paintEvent (QPaintEvent *e);
    void resizeEvent (QResizeEvent *e);
private:
    void draw();
    QImage loadImage (int);
    
public slots:
    void showPopup (QPoint pos);
protected slots:
    void iconClicked (QIconViewItem *, const QPoint &);
};

#endif
